'use strict';

/* For ESLint: List any global identifiers used in this file below */
/* global BGcall, rightclickedItem:true, translate, BlacklistUi,
bindEnterClickToDefault, mayOpenDialogUI:true */

// Global lock so we can't open more than once on a tab.
let mayOpenDialogUI;
if (typeof mayOpenDialogUI === 'undefined') {
  mayOpenDialogUI = true;
}

function topOpenBlacklistUI(options) {
  if (!mayOpenDialogUI) {
    return;
  }

  let parsedOptions;
  if (typeof options === 'string') {
    try {
      parsedOptions = JSON.parse(options);
    } catch (ex) {
      parsedOptions = {};
      parsedOptions.nothing_clicked = true;
    }
  }

  mayOpenDialogUI = false;

  // Get Flash objects out of the way of our UI
  BGcall('emitPageBroadcast', { fn: 'sendContentToBack', options: {} });

  // If they chose "Block an ad on this page..." ask them to click the ad
  if (parsedOptions.nothing_clicked) {
    rightclickedItem = null;
  }

  // If they right clicked in a frame, use the frame instead
  if (parsedOptions.info && parsedOptions.info.frameUrl) {
    const frame = $('iframe').filter((i, el) => el.src === parsedOptions.info.frameUrl);

    if (frame.length === 1) {
      [rightclickedItem] = frame;
    }
  }

  if (typeof rightclickedItem !== 'undefined' && rightclickedItem && rightclickedItem.nodeName === 'BODY') {
    rightclickedItem = null;
  }

  // check if we're running on website with a frameset, if so, tell
  // the user we can't run on it.
  if ($('frameset').length >= 1) {
    // eslint-disable-next-line no-alert
    alert(translate('wizardcantrunonframesets'));
    mayOpenDialogUI = true;
    $('.adblock-ui-stylesheet').remove();
    return;
  }

  BGcall('getSettings', (settings) => {
    const advancedUser = settings.show_advanced_options;
    const blacklistUI = new BlacklistUi(rightclickedItem, advancedUser);
    blacklistUI.cancel(() => {
      mayOpenDialogUI = true;
    });

    blacklistUI.block(() => {
      mayOpenDialogUI = true;

      // In case of frames, reload, as the frame might contain matches too.
      if ($('iframe, frameset, frame').filter(':visible').length > 0) {
        document.location.reload();
      }
    });

    blacklistUI.show();
  });

  bindEnterClickToDefault();
}

// required return value for tabs.executeScript
/* eslint-disable-next-line no-unused-expressions */
'';

// # sourceURL=/uiscripts/topOpenBlacklistUI.js
